Search - Trident Chemwidgets - Docs v0.1

Hide navigation sidebar
Hide table of contents sidebar

Getting started

- Introduction
- Installation

Usage

- Widgets
  Toggle child pages in navigation
  - Histogram
  - InteractiveMolecule
  - JSME
  - Scatter
- Examples
  Toggle child pages in navigation
  - Using the Histogram widget
  - Using the InteractiveMolecule widget
  - Using the JSME widget
  - Using the Scatter widget

Development

- Developer install

API

- trident-chemwidgets
  Toggle child pages in navigation
  - setup module
  - trident_chemwidgets package
    Toggle child pages in navigation
    - trident_chemwidgets.tests package
    - trident_chemwidgets.widgets package

Back to top
Toggle table of contents sidebar